@@ -285,6 +285,17 @@ def overall_report(limit: int = 0):
     print(json.dumps(exporter.overall_report(members=None, limit=limit)))
 
 
+@click.command()
+@transaction.atomic()
+def count_members_from_argentina():
+    """Process each member"""
+    import exporter
+
+    import json
+
+    print(exporter.count_a())
+
+
 @click.command()
 @click.argument("member_id")
 @transaction.atomic()
@@ -530,6 +541,7 @@ def test():
 
 if __name__ == "__main__":
     cli.add_command(clear_cache)
+    cli.add_command(count_members_from_argentina)
     cli.add_command(draw_graphs)
     cli.add_command(import_all)
     cli.add_command(import_cariniana)
