@@ -619,6 +619,64 @@ def rescore_member(
         raise e
 
 
+def count_a():
+    import boto3
+    import logging
+
+    s3client = boto3.client("s3")
+    session = boto3.Session()
+    s3 = session.resource("s3")
+
+    # get member list from S3
+    members = get_members(
+        s3client=s3client,
+        samples_bucket=SAMPLES_BUCKET,
+        samples_path=SAMPLES_PATH,
+    )
+
+    plus_token = os.environ.get("CROSSREF_PLUS_TOKEN", None)
+
+    from crossref.restful import Etiquette, Members
+
+    my_etiquette = Etiquette(
+        "Preservation Status",
+        "0.01",
+        "https://eve.gd",
+        "meve@crossref.org",
+    )
+
+    a_count = 0
+
+    for member in members:
+        logging.info(f"Fetching preservation statistics for member {member}")
+
+        if plus_token:
+            members = Members(
+                etiquette=my_etiquette,
+                crossref_plus_token=plus_token,
+            )
+            logging.info(f"Using plus lookup")
+        else:
+            members = Members(etiquette=my_etiquette)
+            logging.info(f"Using regular lookup")
+
+        logging.info(f"API lookup for {member}: done")
+
+        member_obj = members.member(member)
+
+        if "primary-name" not in member_obj:
+            print(member_obj)
+
+        country = member_obj["location"].split(",")[-1]
+        if country == "Argentina":
+            a_count += 1
+
+            if a_count > 1:
+                return a_count
+
+    return a_count
+
+
 def overall_report(members=None, limit=0):
     import boto3
     import logging
